@@ -1,32 +1,34 @@
-( cd usr/lib/ruby_lib ; rm -rf libhttp11.so )
-( cd usr/lib/ruby_lib ; ln -sf libhttp11.so.0.0.0 libhttp11.so )
-( cd usr/lib/ruby_lib ; rm -rf libhttp11.so.0 )
-( cd usr/lib/ruby_lib ; ln -sf libhttp11.so.0.0.0 libhttp11.so.0 )
-( cd usr/lib ; rm -rf libamarok.so )
-( cd usr/lib ; ln -sf libamarok.so.0.0.0 libamarok.so )
 ( cd usr/lib ; rm -rf libamarok.so.0 )
 ( cd usr/lib ; ln -sf libamarok.so.0.0.0 libamarok.so.0 )
-( cd usr/share/doc/HTML/pt_BR/amarok ; rm -rf common )
-( cd usr/share/doc/HTML/pt_BR/amarok ; ln -sf /usr/share/doc/HTML/pt_BR/common common )
-( cd usr/share/doc/HTML/da/amarok ; rm -rf common )
-( cd usr/share/doc/HTML/da/amarok ; ln -sf /usr/share/doc/HTML/da/common common )
-( cd usr/share/doc/HTML/it/amarok ; rm -rf common )
-( cd usr/share/doc/HTML/it/amarok ; ln -sf /usr/share/doc/HTML/it/common common )
-( cd usr/share/doc/HTML/pt/amarok ; rm -rf common )
-( cd usr/share/doc/HTML/pt/amarok ; ln -sf /usr/share/doc/HTML/pt/common common )
-( cd usr/share/doc/HTML/en/amarok ; rm -rf common )
-( cd usr/share/doc/HTML/en/amarok ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/lib ; rm -rf libamarok.so )
+( cd usr/lib ; ln -sf libamarok.so.0.0.0 libamarok.so )
+( cd usr/lib/ruby_lib ; rm -rf libhttp11.so.0 )
+( cd usr/lib/ruby_lib ; ln -sf libhttp11.so.0.0.0 libhttp11.so.0 )
+( cd usr/lib/ruby_lib ; rm -rf libhttp11.so )
+( cd usr/lib/ruby_lib ; ln -sf libhttp11.so.0.0.0 libhttp11.so )
 ( cd usr/share/doc/HTML/ru/amarok ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/amarok ; ln -sf /usr/share/doc/HTML/ru/common common )
-( cd usr/share/doc/HTML/pl/amarok ; rm -rf common )
-( cd usr/share/doc/HTML/pl/amarok ; ln -sf /usr/share/doc/HTML/pl/common common )
-( cd usr/share/doc/HTML/sv/amarok ; rm -rf common )
-( cd usr/share/doc/HTML/sv/amarok ; ln -sf /usr/share/doc/HTML/sv/common common )
-( cd usr/share/doc/HTML/et/amarok ; rm -rf common )
-( cd usr/share/doc/HTML/et/amarok ; ln -sf /usr/share/doc/HTML/et/common common )
-( cd usr/share/doc/HTML/de/amarok ; rm -rf common )
-( cd usr/share/doc/HTML/de/amarok ; ln -sf /usr/share/doc/HTML/de/common common )
-( cd usr/share/doc/HTML/nl/amarok ; rm -rf common )
-( cd usr/share/doc/HTML/nl/amarok ; ln -sf /usr/share/doc/HTML/nl/common common )
 ( cd usr/share/doc/HTML/fr/amarok ; rm -rf common )
 ( cd usr/share/doc/HTML/fr/amarok ; ln -sf /usr/share/doc/HTML/fr/common common )
+( cd usr/share/doc/HTML/pt_BR/amarok ; rm -rf common )
+( cd usr/share/doc/HTML/pt_BR/amarok ; ln -sf /usr/share/doc/HTML/pt_BR/common common )
+( cd usr/share/doc/HTML/de/amarok ; rm -rf common )
+( cd usr/share/doc/HTML/de/amarok ; ln -sf /usr/share/doc/HTML/de/common common )
+( cd usr/share/doc/HTML/pt/amarok ; rm -rf common )
+( cd usr/share/doc/HTML/pt/amarok ; ln -sf /usr/share/doc/HTML/pt/common common )
+( cd usr/share/doc/HTML/nl/amarok ; rm -rf common )
+( cd usr/share/doc/HTML/nl/amarok ; ln -sf /usr/share/doc/HTML/nl/common common )
+( cd usr/share/doc/HTML/pl/amarok ; rm -rf common )
+( cd usr/share/doc/HTML/pl/amarok ; ln -sf /usr/share/doc/HTML/pl/common common )
+( cd usr/share/doc/HTML/et/amarok ; rm -rf common )
+( cd usr/share/doc/HTML/et/amarok ; ln -sf /usr/share/doc/HTML/et/common common )
+( cd usr/share/doc/HTML/da/amarok ; rm -rf common )
+( cd usr/share/doc/HTML/da/amarok ; ln -sf /usr/share/doc/HTML/da/common common )
+( cd usr/share/doc/HTML/es/amarok ; rm -rf common )
+( cd usr/share/doc/HTML/es/amarok ; ln -sf /usr/share/doc/HTML/es/common common )
+( cd usr/share/doc/HTML/sv/amarok ; rm -rf common )
+( cd usr/share/doc/HTML/sv/amarok ; ln -sf /usr/share/doc/HTML/sv/common common )
+( cd usr/share/doc/HTML/it/amarok ; rm -rf common )
+( cd usr/share/doc/HTML/it/amarok ; ln -sf /usr/share/doc/HTML/it/common common )
+( cd usr/share/doc/HTML/en/amarok ; rm -rf common )
+( cd usr/share/doc/HTML/en/amarok ; ln -sf /usr/share/doc/HTML/en/common common )
